# IHAN Client

[![Documentation Status](https://readthedocs.org/projects/ihan/badge/?version=latest)](http://ihan.readthedocs.io/en/latest/)
[![Build Status](https://travis-ci.org/marklit/ihan.svg?branch=master)](https://travis-ci.org/marklit/whois)
[![Coverage Status](https://coveralls.io/repos/marklit/ihan/badge.png)](https://coveralls.io/r/marklit/whois)
[![Code Health](https://landscape.io/github/marklit/ihan/master/landscape.svg?style=flat)](https://landscape.io/github/marklit/ihan/master)
[![Latest Release](https://img.shields.io/pypi/v/ihan.svg)](https://pypi.python.org/pypi/ihan)
[![license](http://img.shields.io/badge/license-MIT-red.svg?style=flat)](http://opensource.org/licenses/MIT)

This is the installation and usage guide for the [IHAN](https://www.ihan.ee/) Client. This utility is used for feeding and back filling log files to the IHAN service.

Please see the [installation and usage guide](https://ihan.readthedocs.io/en/latest/) for further information.
